<?php
// ------------------------------------------------------------------
//   Google Analytics Tag for Mobile オプション管理
// ------------------------------------------------------------------
$gatm_options = array();

if ( ! defined( 'GATM_OPT_TABLE_KEY' ) )
	define( 'GATM_OPT_TABLE_KEY', 'googleAnalytics_for_KtaiStyle' );

// -------------------------
//  オプションページ関連
// -------------------------

// アカウントIDの初期値を取得する
function gatm_get_default_account_id() {
	// 既にUltimate Google Analyticsをインストールしている場合は
	// そこで設定したアカウントIDを初期値として利用する
	$ua_opts = get_option('ultimate_ga_options');
	if (!is_array($ua_opts) || !isset($ua_opts['account_id'])) {
		return 'MO-XXXXXX-X';
	}
	$ua_account_id = $ua_opts['account_id'];
	$account_id = str_replace('UA-', 'MO-', $ua_account_id);
	return $account_id;
}

// WordPressのオプションテーブルからオプション値を取得する
// オプションがまだなければ初期値を返す
function gatm_get_option($option_name) {
	global $gatm_options;

	// オプションデータをまだ読んでないなら、DB値を取得
	if (empty($gatm_options)) {
		$opts = get_option(GATM_OPT_TABLE_KEY); 
		if ($opts) $gatm_options = $opts; 
	}
	// DBデータがないか、指定のオプション名が存在しない場合は初期値をセット
	if (empty($gatm_options) || !array_key_exists($option_name, $gatm_options)) {
		$default_opts = array(
			'account_id' 				=> gatm_get_default_account_id(),
			'enable_tracker' 			=> true,
			'ignore_users' 				=> true,
			'uri_ignore_ks_params' 		=> true,
			'uri_ignore_guid' 			=> true,
		);
		if (empty($gatm_options)) {
			$gatm_options = $default_opts;
		} else {
			$gatm_options = array_merge($default_opts, $gatm_options);
		}
		// ついでにオプション初期値をDBにセットする。
		add_option( GATM_OPT_TABLE_KEY, $gatm_options);
	}
	return $gatm_options[$option_name];
}

function gatm_show_option_page() {
	global $gatm_options;

	if (isset($_POST['info_update'])) {
	    // オプションの保存
	    $gatm_options = get_option('googleAnalytics_for_KtaiStyle');
	    $gatm_options['account_id']             = $_POST['account_id'];
	    $gatm_options['enable_tracker']         = ($_POST['enable_tracker']=="true"          ? true : false);
	    $gatm_options['ignore_users']           = ($_POST['ignore_users']=="true"            ? true : false);
	    $gatm_options['uri_ignore_ks_params']   = ($_POST['uri_ignore_ks_params']=="true"    ? true : false);
	    $gatm_options['uri_ignore_guid']        = ($_POST['uri_ignore_guid']=="true"         ? true : false);
	    update_option('googleAnalytics_for_KtaiStyle', $gatm_options);
	    ?>
			<div class="updated"><p><strong><?php _e('Options saved', 'gatm') ?></strong></p></div>
		<?php
	} 

	// show options form with current values
	require_once(GATM_PLUGIN_DIR . '/option-edit.php');
}

// 多言語対応
function gatm_load_plugin_textdomain() {
	$plugin_name = dirname( plugin_basename(__FILE__) );
	load_plugin_textdomain( 'gatm', false, $plugin_name . '/languages' );
}
add_action( 'init', 'gatm_load_plugin_textdomain' );

// 設定画面のCSS
function gatm_put_setting_css() {
	$path = WP_PLUGIN_URL . '/' . GATM_PLUGIN_NAME . '/setting.css';
    echo '<link rel="stylesheet" type="text/css" href="' . $path . '" />';
}
add_action('admin_head-settings_page_google-analytics-tag-for-mobile/ga-tag-for-mobile', 'gatm_put_setting_css');


// -------------------------
//  プラグイン一覧関連
// -------------------------

// 管理者向けの「設定」メニューにプラグイン設定画面へのリンクを作成する
function gatm_admin() {
	if (function_exists('add_options_page')) {
		add_options_page('Google Analytics Tag for Mobile' /* page title */, 
						 'GoogleAnalytics Tag for Mobile' /* menu title */, 
						 'administrator' /* 実行可能ユーザー権限（WP2.0以降は数字は駄目） */, 
						 GATM_PLUGIN_BASENAME /* php file */ , 
						 'gatm_show_option_page' /* function for subpanel */);
	}
}

// プラグイン一覧に設定ページへのリンクを貼る
function gatm_add_config_link_to_plugin_list( $links, $file ){
	static $this_plugin;
	if ( ! $this_plugin ) $this_plugin = GATM_PLUGIN_BASENAME;

	if ( $file == $this_plugin ){
		$settings_link = '<a href="options-general.php?page=' . $this_plugin . '">' . __('Settings', 'gatm') . '</a>';
		array_push( $links, $settings_link );
	}
	return $links;
}
// 管理者向けの「設定」メニューにプラグイン設定画面へのリンクを作成する
add_action('admin_menu', 'gatm_admin');

// プラグイン一覧に設定ページへのリンクを貼る
add_filter( 'plugin_action_links', 'gatm_add_config_link_to_plugin_list', 10, 2 );

?>